@@ -4,8 +4,8 @@ use lib './blib/lib/';
 use Net::MDNS::Client ':all';
 
 my $q = make_query("host by service", "", "local.", "perl", "tcp");
-print "Query is $q\n";
-query( $q, "host by service");
+print "Query is !$q!\n";
+query( "host by service", $q);
 
 while (1)
 	{
@@ -13,7 +13,7 @@ while (1)
 			{
 				while (1) {
 				#print "Found host: ",join(", ", get_a_result($q, "host by service")), "\n";
-				print "Found host: ",scalar(get_a_result($q, "host by service")), "\n";
+				print "Found host: ",scalar(get_a_result("host by service", $q)), "\n";
 				sleep 1;
 				}
 			}
